
/*
 * Written by Scott Auge scott_auge@yahoo.com sauge@amduus.com
 * Copyright (c) 2001 Amduus Information Works, Inc.  www.amduus.com
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes software developed by Amduus Information Works
 *      and its contributors.
 * 4. Neither the name of Amduus Information Works, Inc. nor the names of 
 *    its contributors may be used to endorse or promote products derived 
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY AMDUUS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AMDUUS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */


/* 
 * Login.p
 * Written by Scott Auge
 *
 * Login API
 *
 * All business logic is stored in these API for logging in a user.
 *
 */

DEF VAR RCSVersion AS CHARACTER INIT "$Header: /home/appl/srvexp/src/web/RCS/Login.p,v 1.2 2001/12/11 05:53:23 sauge Exp $" NO-UNDO.

DEF INPUT PARAMETER cSessionID AS CHARACTER NO-UNDO.
DEF INPUT PARAMETER pUserID    AS CHARACTER NO-UNDO.
DEF INPUT PARAMETER pPassword  AS CHARACTER NO-UNDO.
DEF OUTPUT PARAMETER pError    AS CHARACTER NO-UNDO.

{api/Error.inc}

/* Determine if such a user exists.  We do locking check so that the API */
/* doesn't hold up the calling program if it is to generate an immediate */
/* response (like a web page.)                                           */

FIND SystemUser NO-LOCK
WHERE SystemUser.LoginID = pUserID
NO-ERROR.

IF NOT AVAILABLE SystemUser THEN
  IF LOCKED SystemUser THEN DO:
    ASSIGN pError = {&LOCKED}.
    RETURN.
  END.
  ELSE DO:
    ASSIGN pError = {&BADUSER}.
    RETURN.
  END.

/* If the user is inactive, we dont want them! */

IF SystemUser.Active = NO THEN DO:
  ASSIGN pError = {&INACTIVE}.
  RETURN.
END.

/* Check if the password matches */

IF pPassword <> SystemUser.Password THEN DO:

  ASSIGN pError = {&MISMATCHPASSWORD}.
  RETURN.

END.

RUN api/state/SetLogin.p (INPUT cSessionID,
                          INPUT  pUserID,
                          OUTPUT pError).


