
/*
 * Written by Scott Auge scott_auge@yahoo.com sauge@amduus.com
 * Copyright (c) 2001 Amduus Information Works, Inc.  www.amduus.com
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes software developed by Amduus Information Works
 *      Inc. and its contributors.
 * 4. Neither the name of Amduus Information Works, Inc. nor the names of 
 *    its contributors may be used to endorse or promote products derived 
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY AMDUUS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AMDUUS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */


/*---------------------------------------------------------------------------
 *
 * Create.p
 *
 * Written by Scott Auge
 *
 * Create a ticket.
 *
 *---------------------------------------------------------------------------
 */

DEF VAR RCSVersion AS CHARACTER INIT "$Header: /home/appl/srvexp/srcpub/api/ticket/RCS/Create.p,v 1.4 2003/05/06 22:59:47 sauge Exp sauge $" NO-UNDO.

DEF INPUT PARAMETER pLoginID        AS CHARACTER NO-UNDO.
DEF INPUT PARAMETER pAddressSeq     AS CHARACTER NO-UNDO.
DEF INPUT PARAMETER pSOW            AS CHARACTER NO-UNDO.
DEF INPUT PARAMETER pShortStatement AS CHARACTER NO-UNDO.
DEF INPUT PARAMETER pTicketTypeSeq  AS CHARACTER NO-UNDO.
DEF INPUT PARAMETER pProblemTypeSeq AS CHARACTER NO-UNDO.
  
DEF OUTPUT PARAMETER pTicketSeq     AS CHARACTER NO-UNDO.
DEF OUTPUT PARAMETER pError         AS CHARACTER NO-UNDO.

DEF VAR lTicketNumber               AS CHARACTER NO-UNDO.
DEF VAR lNoteText                   AS CHARACTER NO-UNDO.
DEF VAR lTicketNoteSeq              AS CHARACTER NO-UNDO.

{api/Error.inc}
{MakeID2.i}
{Log.i}

{LogIt.i '"Begin Program"'}

/* Be sure of our User */

FIND SystemUser NO-LOCK
WHERE SystemUser.LoginID = pLoginID
NO-ERROR.

IF NOT AVAILABLE SystemUser THEN DO:

  ASSIGN pError = {&BADUSER}.
  RETURN.

END. /* No such User! */

/* Find Acillary data associated with this systemuser */

FIND Person OF SystemUser NO-LOCK NO-ERROR.

FIND Contact OF Person NO-LOCK NO-ERROR.

/* Lets go about making a ticket */

CREATE Ticket.

ASSIGN
Ticket.PersonID = Person.PersonID
Ticket.Statement = pSOW
Ticket.AddressSeq = pAddressSeq
Ticket.TicketTypeSeq = pTicketTypeSeq
Ticket.ProblemTypeSeq = pProblemTypeSeq
Ticket.ShortStatement = pShortStatement
Ticket.CompanySeq = SystemUser.CustomerSeq
Ticket.IsWIP = TRUE.

/* Go get the next ticket number */

RUN api/ticket/getnumber.p (OUTPUT lTicketNumber).

ASSIGN Ticket.Reference = lTicketNumber.

/* Defaults */

ASSIGN Ticket.TicketSeq = MakeID2(10).

/* Call to SetStatus with a ? as the StatusSeq will cause API to use */
/* default status for the TicketType.                                */

RUN api/ticket/SetStatus.p (INPUT Ticket.TicketSeq,
                            INPUT ?,
                            OUTPUT pError).

/* Call to SetPriority with a ? as the PrioritySeq will cause the API */
/* to use the default priority for the problem type.                  */

RUN api/ticket/SetPriority.p (INPUT Ticket.TicketSeq,
/*                              INPUT Ticket.TicketTypeSeq, */
                              INPUT ?,
                              OUTPUT pError).

/* Add a note to the ticket about who created it, status, and when.  */

FIND TicketStatus OF Ticket NO-LOCK.

ASSIGN lNoteText = "Status: " 
                 + TicketStatus.Name 
                 + " by " + Person.FirstName + " " + Person.LastName.

RUN api/records/AddTicketNote.p (INPUT Ticket.TicketSeq,
                                 INPUT lNoteText,
                                 OUTPUT lTicketNoteSeq,
                                 OUTPUT pError).

/* Send back the API's message */

ASSIGN 
pTicketSeq = Ticket.TicketSeq.

ASSIGN
pError = {&NOERROR}.
