

/*
 * Written by Scott Auge scott_auge@yahoo.com sauge@amduus.com
 * Copyright (c) 2001 Amduus Information Works, Inc.  www.amduus.com
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes software developed by Amduus Information Works
 *      Inc. and its contributors.
 * 4. Neither the name of Amduus Information Works, Inc. nor the names of 
 *    its contributors may be used to endorse or promote products derived 
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY AMDUUS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AMDUUS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

/* Determine if a user assigned to the ticket is acceptable given the */
/* status.  Good for use to determine if the routing algorithm needs  */
/* to be called.  If the routing alg is called, and others apply, the */
/* ticket might be re-assigned to another person other than who has   */
/* and can handle it - causing chaos in the calling department.       */

DEF INPUT PARAMETER pEmployeeSeq AS CHARACTER NO-UNDO.
DEF INPUT PARAMETER pTicketSeq   AS CHARACTER NO-UNDO.
DEF OUTPUT PARAMETER pIsGood     AS LOGICAL NO-UNDO.
DEF OUTPUT PARAMETER pError      AS CHARACTER NO-UNDO.

{api/Error.inc}
{Log.i}

{LogIt.i '"Begin Program"'}

/* Pick up the ticket cuz we need to find the status */

FIND Ticket NO-LOCK
WHERE Ticket.TicketSeq = pTicketSeq
NO-ERROR.

IF NOT AVAILABLE Ticket THEN DO:

  ASSIGN pError = {&NORECORD}.
  RETURN.

END. /* IF NOT AVAILABLE Ticket */

/* Make sure the employee is OK */

FIND Employee NO-LOCK
WHERE Employee.EmployeeSeq = pEmployeeSeq
NO-ERROR.

IF NOT AVAILABLE Employee THEN DO:

  ASSIGN pError = {&NORECORD}.
  RETURN.

END. /* IF NOT AVAILABLE Employee */

/* Determine if position good for the ticket status */

FOR EACH Route NO-LOCK
WHERE Route.TicketStatusSeq = Ticket.TicketStatusSeq:

  /* If the routing for this ticket status has the employee's  */
  /* position in it, then we are good to go.  Say so and bail. */

  IF Route.PositionSeq = Employee.PositionSeq THEN DO:
    ASSIGN pisGood = YES.
    ASSIGN pError = {&NOERROR}.
    RETURN.
  END. /* IF Route.PositionSeq = Employee.PositionSeq */

END. /* FOR EACH Route */

ASSIGN 
pIsGood = NO
pError = {&NOERROR}.
