
/*
 * Written by Scott Auge scott_auge@yahoo.com sauge@amduus.com
 * Copyright (c) 2001 Amduus Information Works, Inc.  www.amduus.com
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes software developed by Amduus Information Works
 *      Inc. and its contributors.
 * 4. Neither the name of Amduus Information Works, Inc. nor the names of 
 *    its contributors may be used to endorse or promote products derived 
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY AMDUUS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AMDUUS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */


/* SetTicketStatus.p
 *
 * Written by Scott Auge
 */

DEF VAR RCSVersion AS CHARACTER INIT "$Header: /home/appl/srvexp/srcpub/api/ticket/RCS/SetStatus.p,v 1.7 2003/05/06 22:59:47 sauge Exp sauge $" NO-UNDO.

DEF INPUT PARAMETER pTicketSeq        AS CHARACTER NO-UNDO.
DEF INPUT PARAMETER pTicketStatusSeq  AS CHARACTER NO-UNDO.
DEF OUTPUT PARAMETER pError           AS CHARACTER NO-UNDO.

DEF VAR lEmployeeSeq        AS CHARACTER NO-UNDO.
DEF VAR cTicketNoteSeq      AS CHARACTER NO-UNDO.
DEF VAR cError              AS CHARACTER NO-UNDO.

{api/Error.inc}
{Log.i}
{MakeID2.i}

{LogIt.i '"Begin Program"'}
{LogIt.i '"pTicketStatusSeq="' pTicketStatusSeq}

/* When the TicketStatusSeq is ?, that means we intend to use the default */
/* status for the ticket type.                                            */

FIND Ticket EXCLUSIVE-LOCK 
WHERE Ticket.TicketSeq = pTicketSeq
NO-ERROR.

IF NOT AVAILABLE Ticket THEN DO:

  ASSIGN pError = {&NORECORD}.
  RETURN.

END.

{LogIt.i '"TicketProblemSeq "' Ticket.ProblemTypeSeq}

/* A question mark in the status sequence input means set to default */
/* as configured in the configuration screens.                       */

IF pTicketStatusSeq = ? THEN DO:

  FIND TicketStatus NO-LOCK
  WHERE TicketStatus.ProblemTypeSeq = Ticket.ProblemTypeSeq
    AND TicketStatus.IsDefault = YES
  NO-ERROR.

  ASSIGN pTicketStatusSeq = TicketStatus.TicketStatusSeq.

END.

ELSE

  FIND TicketStatus NO-LOCK
  WHERE TicketStatus.TicketStatusSeq = pTicketStatusSeq
  NO-ERROR.

/* If there is a status sequence, we want the status sequence to be put */
/* on the ticket.                                                       */

ASSIGN Ticket.TicketStatusSeq = pTicketStatusSeq.

{LogIt.i '"Ticket assigned Status "' Ticket.TicketStatusSeq}

/* When the status has a HideTicket set to YES, then the ticket is no longer */
/* is work in progress.  This means we need to set IsWIP to NO so it won't   */
/* show up on the lists of the ticket holders.                               */

IF TicketStatus.HideTicket THEN ASSIGN Ticket.IsWIP = NO.
ELSE ASSIGN Ticket.IsWip = YES.

/* Determine which user should get this status ticket.  Manipulate the */
/* TicketAssign table in this routine.  The AssignTicket.p routine is  */
/* a simple API to figure things out.                                  */

{LogIt.i '"Beginning assignment"'}

RUN api/ticket/AssignTicket.p (INPUT ticket.TicketSeq,
                               OUTPUT lEmployeeSeq,
                               OUTPUT pError).

FIND TicketAssign EXCLUSIVE-LOCK
WHERE TicketAssign.TicketSeq = Ticket.TicketSeq
NO-ERROR.

IF NOT AVAILABLE TicketAssign THEN DO:

  CREATE TicketAssign.

  ASSIGN TicketAssign.TicketAssignSeq = MakeID2(10).

  ASSIGN 
  TicketAssign.Active = YES
  TicketAssign.TicketSeq = Ticket.TicketSeq.

END. /* IF NOT AVAILABLE TicketAssign */

ASSIGN TicketAssign.EmployeeSeq = lEmployeeSeq.

ASSIGN Ticket.AssignedTo = lEmployeeSeq.

{LogIt.i '"Ending assignment"'}
