
/*
 * Written by Scott Auge scott_auge@yahoo.com sauge@amduus.com
 * Copyright (c) 2001 Amduus Information Works, Inc.  www.amduus.com
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes software developed by Amduus Information Works
 *      Inc. and its contributors.
 * 4. Neither the name of Amduus Information Works, Inc. nor the names of 
 *    its contributors may be used to endorse or promote products derived 
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY AMDUUS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AMDUUS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */


/*--------------------------------------------------------------------------
 *
 * getnumber.p
 *
 * Returns a new ticket number.
 *
 * Number is yyyy-m-dd-nnnn
 * where 
 * yyyy is four numbers to handle year
 * m is letter representing month:
 *   A = January
 *   B = February
 *   etc.
 * dd is day of month
 * nnnn is number of tickets today
 *--------------------------------------------------------------------------
 */

DEF VAR RCSVersion AS CHARACTER INIT "$Header: /home/appl/srvexp/srcpub/api/ticket/RCS/getnumber.p,v 1.4 2001/12/05 03:24:44 sauge Exp $" NO-UNDO.

DEF OUTPUT PARAMETER pTicketNumber AS CHARACTER NO-UNDO.

DEF VAR Months AS CHARACTER INITIAL "ABCDEFGHIJKL" NO-UNDO.

{Log.i}

{LogIt.i '"Begin Program"'}

ASSIGN
pTicketNumber = STRING(YEAR(TODAY), "9999")
              + "-"
              + SUBSTRING(Months, MONTH(TODAY), 1)
              + "-"
              + STRING(DAY(TODAY), "99")
              + "-".

/* Look up how many tickets have been created today.  This is stored in a */
/* record.  If the day has changed since the LAST time the record was up- */
/* dated, then reset to 00000.  If there is no such record, then create   */
/* one and set things a going.                                            */

FIND Counter EXCLUSIVE-LOCK
WHERE Counter.Name = "TicketCount"
NO-ERROR.

IF NOT AVAILABLE Counter THEN DO:

  CREATE Counter.

  ASSIGN 
  Counter.Name = "TicketCount"
  Counter.UsedDate = TODAY
  Counter.KeyValue = 0.

END. /* NOT AVAILABLE Counter */

IF Counter.UsedDate <> TODAY THEN DO:

  ASSIGN
  Counter.UsedDate = TODAY
  Counter.KeyValue = 0.

END. /* Counter LAST used previous to today */

ASSIGN
Counter.KeyValue = Counter.KeyValue + 1.

ASSIGN
pTicketNumber = pTicketNumber + STRING (Counter.KeyValue, "99999").



